@@ -83,9 +83,7 @@ struct parameter param = {
 #ifdef FIFO
 	,NULL
 #endif
-#if !defined (WIN32) || defined (__CYGWIN__)
 	,0 /* timeout */
-#endif
 	,1 /* loop */
 	,0 /* delay */
 	,0 /* index */
@@ -133,7 +131,11 @@ size_t bufferblock = 0;
 static int intflag = FALSE;
 static int skip_tracks = 0;
 int OutputDescriptor;
+
 static int filept = -1;
+
+static int network_sockets_used = 0; /* Win32 socket open/close Support */
+
 char *binpath; /* Path to myself. */
 
 /* File-global storage of command line arguments.
@@ -191,7 +193,9 @@ void safe_exit(int code)
 #ifdef WIN32_WANT_UNICODE
 	win32_cmdline_free(argc, argv); /* This handles the premature argv == NULL, too. */
 #endif
-
+#if defined (WANT_WIN32_SOCKETS)
+	win32_net_deinit();
+#endif
 	/* It's ugly... but let's just fix this still-reachable memory chunk of static char*. */
 	split_dir_file("", &dummy, &dammy);
 	exit(code);
@@ -200,7 +204,7 @@ void safe_exit(int code)
 /* returns 1 if reset_audio needed instead */
 static void set_output_module( char *arg )
 {
-	int i;
+	unsigned int i;
 		
 	/* Search for a colon and set the device if found */
 	for(i=0; i< strlen( arg ); i++) {
@@ -317,7 +321,7 @@ static void set_out_stdout1(char *arg)
 	#endif
 }
 
-#ifndef HAVE_SCHED_SETSCHEDULER
+#if !defined (HAVE_SCHED_SETSCHEDULER) && !defined (HAVE_WINDOWS_H)
 static void realtime_not_compiled(char *arg)
 {
 	fprintf(stderr,"Option '-T / --realtime' not compiled into this binary.\n");
@@ -442,9 +446,7 @@ topt opts[] = {
 #ifdef FIFO
 	{0, "fifo", GLO_ARG | GLO_CHAR, 0, &param.fifo,  0},
 #endif
-#ifndef WIN32
 	{0, "timeout", GLO_ARG | GLO_LONG, 0, &param.timeout, 0},
-#endif
 	{0, "loop", GLO_ARG | GLO_LONG, 0, &param.loop, 0},
 	{'i', "index", GLO_INT, 0, &param.index, 1},
 	{'D', "delay", GLO_ARG | GLO_INT, 0, &param.delay, 0},
@@ -510,6 +512,20 @@ static void reset_audio(long rate, int channels, int format)
 #endif
 }
 
+static int open_track_fd (void)
+{
+	/* Let reader handle invalid filept */
+	if(mpg123_open_fd(mh, filept) != MPG123_OK)
+	{
+		error2("Cannot open fd %i: %s", filept, mpg123_strerror(mh));
+		return 0;
+	}
+	debug("Track successfully opened.");
+	fresh = TRUE;
+	return 1;
+	/*1 for success, 0 for failure */
+}
+
 /* 1 on success, 0 on failure */
 int open_track(char *fname)
 {
@@ -523,10 +539,20 @@ int open_track(char *fname)
 #ifdef WIN32
 		_setmode(STDIN_FILENO, _O_BINARY);
 #endif
+		return open_track_fd();
 	}
 	else if (!strncmp(fname, "http://", 7)) /* http stream */
 	{
-		filept = http_open(fname, &htd);
+#if defined (WANT_WIN32_SOCKETS)
+	/*Use recv instead of stdio functions */
+	win32_net_replace(mh);
+	filept = win32_net_http_open(fname, &htd);
+#else
+	filept = http_open(fname, &htd);
+#endif
+	network_sockets_used = 1;
+/* utf-8 encoded URLs might not work under Win32 */
+		
 		/* now check if we got sth. and if we got sth. good */
 		if(    (filept >= 0) && (htd.content_type.p != NULL)
 			  && !param.ignore_mime && !(debunk_mime(htd.content_type.p) & IS_FILE) )
@@ -546,13 +572,9 @@ int open_track(char *fname)
 	}
 	debug("OK... going to finally open.");
 	/* Now hook up the decoder on the opened stream or the file. */
-	if(filept > -1)
+	if(network_sockets_used) 
 	{
-		if(mpg123_open_fd(mh, filept) != MPG123_OK)
-		{
-			error2("Cannot open fd %i: %s", filept, mpg123_strerror(mh));
-			return 0;
-		}
+		return open_track_fd();
 	}
 	else if(mpg123_open(mh, fname) != MPG123_OK)
 	{
@@ -568,6 +590,13 @@ int open_track(char *fname)
 void close_track(void)
 {
 	mpg123_close(mh);
+#if defined (WANT_WIN32_SOCKETS)
+	if (network_sockets_used)
+	win32_net_close(filept);
+	filept = -1;
+	return;
+#endif
+	network_sockets_used = 0;
 	if(filept > -1) close(filept);
 	filept = -1;
 }
@@ -698,24 +727,6 @@ int skip_or_die(struct timeval *start_time)
 #define skip_or_die(a) TRUE
 #endif
 
-#if defined (WANT_WIN32_UNICODE)
-static int
-argv_cleanup(void *in)
-{
-	debug ("argv_cleanup running!\n");
-	char ** ptr;
-	ptr = (char **)in;
-	while (ptr && *ptr) 
-	{
-		free ((void *)*ptr);
-		++ptr;
-	}
-	free(in);
-	debug ("argv_cleanup ran!\n");
-	return 0;
-}
-#endif
-
 int main(int sys_argc, char ** sys_argv)
 {
 	int result;
@@ -737,6 +748,9 @@ int main(int sys_argc, char ** sys_argv)
 	argv = sys_argv;
 	argc = sys_argc;
 #endif
+#if defined (WANT_WIN32_SOCKETS)
+	win32_net_init();
+#endif
 
 	/* Extract binary and path, take stuff before/after last / or \ . */
 	if((prgName = strrchr(argv[0], '/')) || (prgName = strrchr(argv[0], '\\')))
@@ -876,10 +890,8 @@ int main(int sys_argc, char ** sys_argv)
 	    && MPG123_OK == (result = mpg123_par(mp, MPG123_ICY_INTERVAL, 0, 0))
 	    && ++libpar
 	    && MPG123_OK == (result = mpg123_par(mp, MPG123_RESYNC_LIMIT, param.resync_limit, 0))
-#ifndef WIN32
 	    && ++libpar
 	    && MPG123_OK == (result = mpg123_par(mp, MPG123_TIMEOUT, param.timeout, 0))
-#endif
 	    && ++libpar
 	    && MPG123_OK == (result = mpg123_par(mp, MPG123_OUTSCALE, param.outscale, 0))
 	    && ++libpar
@@ -1212,9 +1224,7 @@ static void long_usage(int err)
 	fprintf(o," -l <n> --listentry <n>    play nth title in playlist; show whole playlist for n < 0\n");
 	fprintf(o,"        --loop <n>         loop track(s) <n> times, < 0 means infinite loop (not with --random!)\n");
 	fprintf(o,"        --keep-open        (--remote mode only) keep loaded file open after reaching end\n");
-#ifndef WIN32
 	fprintf(o,"        --timeout <n>      Timeout in seconds before declaring a stream dead (if <= 0, wait forever)\n");
-#endif
 	fprintf(o," -z     --shuffle          shuffle song-list before playing\n");
 	fprintf(o," -Z     --random           full random play\n");
 	fprintf(o,"        --no-icy-meta      Do not accept ICY meta data\n");
@@ -1259,7 +1269,7 @@ static void long_usage(int err)
 	fprintf(o,"        --8bit             force 8 bit output\n");
 	fprintf(o,"        --float            force floating point output (internal precision)\n");
 	audio_enclist(&enclist);
-	fprintf(o," -e <c> --encoding <c>     force a specific encoding c (%s)\n", enclist != NULL ? enclist : "OOM!");
+	fprintf(o," -e <c> --encoding <c>     force a specific encoding (%s)\n", enclist != NULL ? enclist : "OOM!");
 	fprintf(o," -d n   --doublespeed n    play only every nth frame\n");
 	fprintf(o," -h n   --halfspeed   n    play every frame n times\n");
 	fprintf(o,"        --equalizer        exp.: scales freq. bands acrd. to 'equalizer.dat'\n");
@@ -1284,7 +1294,7 @@ static void long_usage(int err)
 	#ifdef HAVE_TERMIOS
 	fprintf(o," -C     --control          enable terminal control keys\n");
 	#endif
-	#ifndef GENERIG
+	#ifndef GENERIC
 	fprintf(o,"        --title            set xterm/rxvt title to filename\n");
 	#endif
 	fprintf(o,"        --long-tag         spacy id3 display with every item on a separate line\n");
