@@ -33,6 +33,10 @@ static const struct {
 	{ SND_PCM_FORMAT_S8,     MPG123_ENC_SIGNED_8    },
 	{ SND_PCM_FORMAT_A_LAW,  MPG123_ENC_ALAW_8      },
 	{ SND_PCM_FORMAT_MU_LAW, MPG123_ENC_ULAW_8      },
+	{ SND_PCM_FORMAT_S32,    MPG123_ENC_SIGNED_32   },
+	{ SND_PCM_FORMAT_U32,    MPG123_ENC_UNSIGNED_32 },
+	{ SND_PCM_FORMAT_FLOAT,  MPG123_ENC_FLOAT_32    },
+	{ SND_PCM_FORMAT_FLOAT64, MPG123_ENC_FLOAT_64   }
 };
 #define NUM_FORMATS (sizeof format_map / sizeof format_map[0])
 
@@ -136,7 +140,7 @@ static int initialize_device(audio_output_t *ao)
 	return 0;
 }
 
-void error_ignorer(const char *file, int line, const char *function, int err, const char *fmt,...)
+static void error_ignorer(const char *file, int line, const char *function, int err, const char *fmt,...)
 {
 	/* I can make ALSA silent. */
 }
@@ -147,7 +151,8 @@ static int open_alsa(audio_output_t *ao)
 	snd_pcm_t *pcm=NULL;
 	debug1("open_alsa with %p", ao->userptr);
 
-	snd_lib_error_set_handler(AOQUIET ? error_ignorer : NULL);
+	if(AOQUIET) snd_lib_error_set_handler(error_ignorer);
+
 	pcm_name = ao->device ? ao->device : "default";
 	if (snd_pcm_open(&pcm, pcm_name, SND_PCM_STREAM_PLAYBACK, 0) < 0) {
 		if(!AOQUIET) error1("cannot open device %s", pcm_name);
@@ -230,8 +235,12 @@ static void flush_alsa(audio_output_t *ao)
 	snd_pcm_t *pcm=(snd_pcm_t*)ao->userptr;
 
 	/* is this the optimal solution? - we should figure out what we really whant from this function */
+
+debug("alsa drop");
 	snd_pcm_drop(pcm);
+debug("alsa prepare");
 	snd_pcm_prepare(pcm);
+debug("alsa flush done");
 }
 
 static int close_alsa(audio_output_t *ao)
